<?php

//Setup
function bonyo_setup() {

	//Post Format
	//add_theme_support('post-formats', array('aside', 'audio', 'chat', 'gallery', 'image', 'link', 'quote', 'status', 'video'));
	add_theme_support('post-thumbnails');
	add_theme_support('html5', array('search-form', 'comment-form', 'comment-list', 'gallery', 'caption'));
	add_theme_support("title-tag");
	add_theme_support('automatic-feed-links');
}
add_action('after_setup_theme', 'bonyo_setup');


//Content Width
function bny_content_width() {
    $GLOBALS['content_width'] = apply_filters('bny_content_width', 624);
}
add_action('after_setup_theme', 'bny_content_width', 0);

	
//Load Styles and Scripts
function bny_enq_style_scripts() {

	//style.min.css (style of theme)
	wp_enqueue_style('theme-style', get_stylesheet_directory_uri() . '/style.min.css');

	//Font Awesome 4.7.0
	wp_enqueue_style('fontawesome-style', get_template_directory_uri() . '/fonts/font-awesome-4.7.0/css/font-awesome.min.css');

	//Comment Reply
	if (is_singular() && comments_open()) {
		wp_enqueue_script('comment-reply');
	}

	//Disable Style for block editor (Gutenberg)
	wp_dequeue_style('wp-block-library');

}
add_action('wp_enqueue_scripts', 'bny_enq_style_scripts');

//replace style meta tag 
function bny_css_async( $tag ) {
	if (!strpos($tag, 'fontawesome-style') === false) {
		$awesome = get_template_directory_uri() . '/fonts/font-awesome-4.7.0/css/font-awesome.min.css';
		$tag =  str_replace('media=\'all\' />', 'media="none" onload="if(media!=\'all\')media=\'all\'"><noscript><link rel="stylesheet" href="'  . $awesome . '"></noscript>', $tag);
	}
	return $tag;
}
add_filter('style_loader_tag', 'bny_css_async' );



//Theme customizer   disable some items.
add_action('customize_register', 'bny_disable_customizer');
function bny_disable_customizer($wp_customize) {
	$wp_customize->remove_section('colors');
	$wp_customize->remove_section('background_image');
	$wp_customize->remove_section('header_image');
	$wp_customize->remove_section('static_front_page');
}



//Nav Menu custom class
class bny_nav_walker extends Walker_Nav_Menu {
	function start_lvl(&$output, $depth = 0, $args = array()) {
		$output .= '<input class="menu-toggle" type="checkbox" /><ul class="sub-menu">';
	}
	function end_lvl(&$output, $depth = 0, $args = array()) {
		$output .= '</ul>';
	}
}



//Sidebar Widget
if (!function_exists('bonyo_widgets_init')):
function bonyo_widgets_init() {
  register_sidebar( array(
    'name'          => esc_html__('Sidebar', 'bonyo'),
    'id'            => 'sidebar-1',
    'description'   => esc_html__('Add widgets here.', 'bonyo'),
    'before_widget' => '<section id="%1$s" class="widget %2$s">',
    'after_widget'  => '</section>',
    'before_title'  => '<h3 class="widget-title">',
    'after_title'   => '</h3>',
  ));
}
endif;
add_action('widgets_init', 'bonyo_widgets_init');



//Search widget form
function bny_search_form($form) {
	$form = '<form role="search" method="get" class="search-form" action="' . esc_url( home_url( '/' )) . '">
	<div>
		<input type="search" class="search-field" placeholder="" value="' . get_search_query() . '" name="s" />
		<input type="submit" class="search-submit" value="&#xf002;" />
	</div>
	</form>';
	return $form;
}
add_filter('get_search_form', 'bny_search_form');



//Read more (excerpt)
function bny_excerpt_more($excerpt) { 
    return $excerpt. ' <div class="read-more"><div class="more-button">' . __('Read more', 'bonyo') . '</div>'; 
}
add_filter('get_the_excerpt', 'bny_excerpt_more');



//Execute CSS minimization script when logging out
function bny_readfile($file){
	require_once(ABSPATH.'wp-admin/includes/file.php');
	$buf = '';
	if (is_file($file) === true){
		if(WP_Filesystem()){
			global $wp_filesystem;
			$buf = $wp_filesystem->get_contents($file);
        }
	}
	return $buf;
}
function bny_writefile($file, $text){
	require_once(ABSPATH.'wp-admin/includes/file.php');
	if(WP_Filesystem()){
		global $wp_filesystem;
		$wp_filesystem->put_contents($file, $text);
	}
}
function exec_css_minimization() {
	$infile = get_template_directory() . '/style.css';
	$outfile = get_template_directory() . '/style.min.css';

	if (is_file($infile) === true){
		$buf = bny_readfile($infile);
		$buf = mincss($buf);
		bny_writefile($outfile, $buf);
	}
}
function mincss($c){
	$c = str_replace(array("\r\n", "\r", "\n", "\t", '  ', '    ', '    '), '', $c);
	$c = preg_replace('!/\*[^*]*\*+([^/][^*]*\*+)*/!', '', $c);
	$c = str_replace(': ', ':', $c);
	return $c;
}
add_action('wp_logout', 'exec_css_minimization');



//Remove Action
remove_action('wp_head', 'wp_generator');	//Hiding "WordPress Version" meta tag.
remove_action('wp_head', 'rsd_link');	//Hiding "RSD(Really Simple Discovery)" meta tag.
remove_action('wp_head', 'wlwmanifest_link');	//Hiding "Windows Live Writer link" meta tag.
remove_action('wp_head', 'rest_output_link_wp_head');	//Hiding "REST API endpoint" 
remove_action('wp_head', 'wp_oembed_add_discovery_links');	//Hiding "oEmbed links"
remove_action('wp_head', 'wp_oembed_add_host_js');	//Hiding "oEmbed JS"
remove_action('wp_head', 'print_emoji_detection_script', 7);	//Hiding Emoji Script
remove_action('wp_print_styles', 'print_emoji_styles');	//Hiding Emoji style



//Disable block editor (Gutenberg Editor)
add_filter('use_block_editor_for_post', '__return_false');

//Disable rich editor
//add_filter('user_can_richedit', '__return_false');

